==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkLabelPlacementMapper.java <==
// java wrapper for vtkLabelPlacementMapper object
//

package vtk;
import vtk.*;

public class vtkLabelPlacementMapper extends vtkMapper2D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void RenderOverlay_2(vtkViewport id0,vtkActor2D id1);
  public void RenderOverlay(vtkViewport id0,vtkActor2D id1)
    { RenderOverlay_2(id0,id1); }

  private native void SetRenderStrategy_3(vtkLabelRenderStrategy id0);
  public void SetRenderStrategy(vtkLabelRenderStrategy id0)
    { SetRenderStrategy_3(id0); }

  private native long GetRenderStrategy_4();
  public vtkLabelRenderStrategy GetRenderStrategy() {
    long temp = GetRenderStrategy_4();

    if (temp == 0) return null;
    return (vtkLabelRenderStrategy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetMaximumLabelFraction_5(double id0);
  public void SetMaximumLabelFraction(double id0)
    { SetMaximumLabelFraction_5(id0); }

  private native double GetMaximumLabelFractionMinValue_6();
  public double GetMaximumLabelFractionMinValue()
    { return GetMaximumLabelFractionMinValue_6(); }

  private native double GetMaximumLabelFractionMaxValue_7();
  public double GetMaximumLabelFractionMaxValue()
    { return GetMaximumLabelFractionMaxValue_7(); }

  private native double GetMaximumLabelFraction_8();
  public double GetMaximumLabelFraction()
    { return GetMaximumLabelFraction_8(); }

  private native void SetIteratorType_9(int id0);
  public void SetIteratorType(int id0)
    { SetIteratorType_9(id0); }

  private native int GetIteratorType_10();
  public int GetIteratorType()
    { return GetIteratorType_10(); }

  private native void SetUseUnicodeStrings_11(boolean id0);
  public void SetUseUnicodeStrings(boolean id0)
    { SetUseUnicodeStrings_11(id0); }

  private native boolean GetUseUnicodeStrings_12();
  public boolean GetUseUnicodeStrings()
    { return GetUseUnicodeStrings_12(); }

  private native void UseUnicodeStringsOn_13();
  public void UseUnicodeStringsOn()
    { UseUnicodeStringsOn_13(); }

  private native void UseUnicodeStringsOff_14();
  public void UseUnicodeStringsOff()
    { UseUnicodeStringsOff_14(); }

  private native boolean GetPositionsAsNormals_15();
  public boolean GetPositionsAsNormals()
    { return GetPositionsAsNormals_15(); }

  private native void SetPositionsAsNormals_16(boolean id0);
  public void SetPositionsAsNormals(boolean id0)
    { SetPositionsAsNormals_16(id0); }

  private native void PositionsAsNormalsOn_17();
  public void PositionsAsNormalsOn()
    { PositionsAsNormalsOn_17(); }

  private native void PositionsAsNormalsOff_18();
  public void PositionsAsNormalsOff()
    { PositionsAsNormalsOff_18(); }

  private native boolean GetGeneratePerturbedLabelSpokes_19();
  public boolean GetGeneratePerturbedLabelSpokes()
    { return GetGeneratePerturbedLabelSpokes_19(); }

  private native void SetGeneratePerturbedLabelSpokes_20(boolean id0);
  public void SetGeneratePerturbedLabelSpokes(boolean id0)
    { SetGeneratePerturbedLabelSpokes_20(id0); }

  private native void GeneratePerturbedLabelSpokesOn_21();
  public void GeneratePerturbedLabelSpokesOn()
    { GeneratePerturbedLabelSpokesOn_21(); }

  private native void GeneratePerturbedLabelSpokesOff_22();
  public void GeneratePerturbedLabelSpokesOff()
    { GeneratePerturbedLabelSpokesOff_22(); }

  private native boolean GetUseDepthBuffer_23();
  public boolean GetUseDepthBuffer()
    { return GetUseDepthBuffer_23(); }

  private native void SetUseDepthBuffer_24(boolean id0);
  public void SetUseDepthBuffer(boolean id0)
    { SetUseDepthBuffer_24(id0); }

  private native void UseDepthBufferOn_25();
  public void UseDepthBufferOn()
    { UseDepthBufferOn_25(); }

  private native void UseDepthBufferOff_26();
  public void UseDepthBufferOff()
    { UseDepthBufferOff_26(); }

  private native void SetPlaceAllLabels_27(boolean id0);
  public void SetPlaceAllLabels(boolean id0)
    { SetPlaceAllLabels_27(id0); }

  private native boolean GetPlaceAllLabels_28();
  public boolean GetPlaceAllLabels()
    { return GetPlaceAllLabels_28(); }

  private native void PlaceAllLabelsOn_29();
  public void PlaceAllLabelsOn()
    { PlaceAllLabelsOn_29(); }

  private native void PlaceAllLabelsOff_30();
  public void PlaceAllLabelsOff()
    { PlaceAllLabelsOff_30(); }

  private native void SetOutputTraversedBounds_31(boolean id0);
  public void SetOutputTraversedBounds(boolean id0)
    { SetOutputTraversedBounds_31(id0); }

  private native boolean GetOutputTraversedBounds_32();
  public boolean GetOutputTraversedBounds()
    { return GetOutputTraversedBounds_32(); }

  private native void OutputTraversedBoundsOn_33();
  public void OutputTraversedBoundsOn()
    { OutputTraversedBoundsOn_33(); }

  private native void OutputTraversedBoundsOff_34();
  public void OutputTraversedBoundsOff()
    { OutputTraversedBoundsOff_34(); }

  private native void SetShape_35(int id0);
  public void SetShape(int id0)
    { SetShape_35(id0); }

  private native int GetShapeMinValue_36();
  public int GetShapeMinValue()
    { return GetShapeMinValue_36(); }

  private native int GetShapeMaxValue_37();
  public int GetShapeMaxValue()
    { return GetShapeMaxValue_37(); }

  private native int GetShape_38();
  public int GetShape()
    { return GetShape_38(); }

  private native void SetShapeToNone_39();
  public void SetShapeToNone()
    { SetShapeToNone_39(); }

  private native void SetShapeToRect_40();
  public void SetShapeToRect()
    { SetShapeToRect_40(); }

  private native void SetShapeToRoundedRect_41();
  public void SetShapeToRoundedRect()
    { SetShapeToRoundedRect_41(); }

  private native void SetStyle_42(int id0);
  public void SetStyle(int id0)
    { SetStyle_42(id0); }

  private native int GetStyleMinValue_43();
  public int GetStyleMinValue()
    { return GetStyleMinValue_43(); }

  private native int GetStyleMaxValue_44();
  public int GetStyleMaxValue()
    { return GetStyleMaxValue_44(); }

  private native int GetStyle_45();
  public int GetStyle()
    { return GetStyle_45(); }

  private native void SetStyleToFilled_46();
  public void SetStyleToFilled()
    { SetStyleToFilled_46(); }

  private native void SetStyleToOutline_47();
  public void SetStyleToOutline()
    { SetStyleToOutline_47(); }

  private native void SetMargin_48(double id0);
  public void SetMargin(double id0)
    { SetMargin_48(id0); }

  private native double GetMargin_49();
  public double GetMargin()
    { return GetMargin_49(); }

  private native void SetBackgroundColor_50(double id0,double id1,double id2);
  public void SetBackgroundColor(double id0,double id1,double id2)
    { SetBackgroundColor_50(id0,id1,id2); }

  private native void SetBackgroundColor_51(double id0[]);
  public void SetBackgroundColor(double id0[])
    { SetBackgroundColor_51(id0); }

  private native double[] GetBackgroundColor_52();
  public double[] GetBackgroundColor()
    { return GetBackgroundColor_52(); }

  private native void SetBackgroundOpacity_53(double id0);
  public void SetBackgroundOpacity(double id0)
    { SetBackgroundOpacity_53(id0); }

  private native double GetBackgroundOpacityMinValue_54();
  public double GetBackgroundOpacityMinValue()
    { return GetBackgroundOpacityMinValue_54(); }

  private native double GetBackgroundOpacityMaxValue_55();
  public double GetBackgroundOpacityMaxValue()
    { return GetBackgroundOpacityMaxValue_55(); }

  private native double GetBackgroundOpacity_56();
  public double GetBackgroundOpacity()
    { return GetBackgroundOpacity_56(); }

  private native long GetAnchorTransform_57();
  public vtkCoordinate GetAnchorTransform() {
    long temp = GetAnchorTransform_57();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void ReleaseGraphicsResources_58(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_58(id0); }

  public vtkLabelPlacementMapper() { super(); }

  public vtkLabelPlacementMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-aarch64.pkg.tar.xz: vtk/vtkLabelPlacementMapper.java <==
// java wrapper for vtkLabelPlacementMapper object
//

package vtk;
import vtk.*;

public class vtkLabelPlacementMapper extends vtkMapper2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void RenderOverlay_2(vtkViewport id0,vtkActor2D id1);
  public void RenderOverlay(vtkViewport id0,vtkActor2D id1)
    { RenderOverlay_2(id0,id1); }

  private native void SetRenderStrategy_3(vtkLabelRenderStrategy id0);
  public void SetRenderStrategy(vtkLabelRenderStrategy id0)
    { SetRenderStrategy_3(id0); }

  private native long GetRenderStrategy_4();
  public vtkLabelRenderStrategy GetRenderStrategy() {
    long temp = GetRenderStrategy_4();

    if (temp == 0) return null;
    return (vtkLabelRenderStrategy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMaximumLabelFraction_5(double id0);
  public void SetMaximumLabelFraction(double id0)
    { SetMaximumLabelFraction_5(id0); }

  private native double GetMaximumLabelFractionMinValue_6();
  public double GetMaximumLabelFractionMinValue()
    { return GetMaximumLabelFractionMinValue_6(); }

  private native double GetMaximumLabelFractionMaxValue_7();
  public double GetMaximumLabelFractionMaxValue()
    { return GetMaximumLabelFractionMaxValue_7(); }

  private native double GetMaximumLabelFraction_8();
  public double GetMaximumLabelFraction()
    { return GetMaximumLabelFraction_8(); }

  private native void SetIteratorType_9(int id0);
  public void SetIteratorType(int id0)
    { SetIteratorType_9(id0); }

  private native int GetIteratorType_10();
  public int GetIteratorType()
    { return GetIteratorType_10(); }

  private native void SetUseUnicodeStrings_11(boolean id0);
  public void SetUseUnicodeStrings(boolean id0)
    { SetUseUnicodeStrings_11(id0); }

  private native boolean GetUseUnicodeStrings_12();
  public boolean GetUseUnicodeStrings()
    { return GetUseUnicodeStrings_12(); }

  private native void UseUnicodeStringsOn_13();
  public void UseUnicodeStringsOn()
    { UseUnicodeStringsOn_13(); }

  private native void UseUnicodeStringsOff_14();
  public void UseUnicodeStringsOff()
    { UseUnicodeStringsOff_14(); }

  private native boolean GetPositionsAsNormals_15();
  public boolean GetPositionsAsNormals()
    { return GetPositionsAsNormals_15(); }

  private native void SetPositionsAsNormals_16(boolean id0);
  public void SetPositionsAsNormals(boolean id0)
    { SetPositionsAsNormals_16(id0); }

  private native void PositionsAsNormalsOn_17();
  public void PositionsAsNormalsOn()
    { PositionsAsNormalsOn_17(); }

  private native void PositionsAsNormalsOff_18();
  public void PositionsAsNormalsOff()
    { PositionsAsNormalsOff_18(); }

  private native boolean GetGeneratePerturbedLabelSpokes_19();
  public boolean GetGeneratePerturbedLabelSpokes()
    { return GetGeneratePerturbedLabelSpokes_19(); }

  private native void SetGeneratePerturbedLabelSpokes_20(boolean id0);
  public void SetGeneratePerturbedLabelSpokes(boolean id0)
    { SetGeneratePerturbedLabelSpokes_20(id0); }

  private native void GeneratePerturbedLabelSpokesOn_21();
  public void GeneratePerturbedLabelSpokesOn()
    { GeneratePerturbedLabelSpokesOn_21(); }

  private native void GeneratePerturbedLabelSpokesOff_22();
  public void GeneratePerturbedLabelSpokesOff()
    { GeneratePerturbedLabelSpokesOff_22(); }

  private native boolean GetUseDepthBuffer_23();
  public boolean GetUseDepthBuffer()
    { return GetUseDepthBuffer_23(); }

  private native void SetUseDepthBuffer_24(boolean id0);
  public void SetUseDepthBuffer(boolean id0)
    { SetUseDepthBuffer_24(id0); }

  private native void UseDepthBufferOn_25();
  public void UseDepthBufferOn()
    { UseDepthBufferOn_25(); }

  private native void UseDepthBufferOff_26();
  public void UseDepthBufferOff()
    { UseDepthBufferOff_26(); }

  private native void SetPlaceAllLabels_27(boolean id0);
  public void SetPlaceAllLabels(boolean id0)
    { SetPlaceAllLabels_27(id0); }

  private native boolean GetPlaceAllLabels_28();
  public boolean GetPlaceAllLabels()
    { return GetPlaceAllLabels_28(); }

  private native void PlaceAllLabelsOn_29();
  public void PlaceAllLabelsOn()
    { PlaceAllLabelsOn_29(); }

  private native void PlaceAllLabelsOff_30();
  public void PlaceAllLabelsOff()
    { PlaceAllLabelsOff_30(); }

  private native void SetOutputTraversedBounds_31(boolean id0);
  public void SetOutputTraversedBounds(boolean id0)
    { SetOutputTraversedBounds_31(id0); }

  private native boolean GetOutputTraversedBounds_32();
  public boolean GetOutputTraversedBounds()
    { return GetOutputTraversedBounds_32(); }

  private native void OutputTraversedBoundsOn_33();
  public void OutputTraversedBoundsOn()
    { OutputTraversedBoundsOn_33(); }

  private native void OutputTraversedBoundsOff_34();
  public void OutputTraversedBoundsOff()
    { OutputTraversedBoundsOff_34(); }

  private native void SetShape_35(int id0);
  public void SetShape(int id0)
    { SetShape_35(id0); }

  private native int GetShapeMinValue_36();
  public int GetShapeMinValue()
    { return GetShapeMinValue_36(); }

  private native int GetShapeMaxValue_37();
  public int GetShapeMaxValue()
    { return GetShapeMaxValue_37(); }

  private native int GetShape_38();
  public int GetShape()
    { return GetShape_38(); }

  private native void SetShapeToNone_39();
  public void SetShapeToNone()
    { SetShapeToNone_39(); }

  private native void SetShapeToRect_40();
  public void SetShapeToRect()
    { SetShapeToRect_40(); }

  private native void SetShapeToRoundedRect_41();
  public void SetShapeToRoundedRect()
    { SetShapeToRoundedRect_41(); }

  private native void SetStyle_42(int id0);
  public void SetStyle(int id0)
    { SetStyle_42(id0); }

  private native int GetStyleMinValue_43();
  public int GetStyleMinValue()
    { return GetStyleMinValue_43(); }

  private native int GetStyleMaxValue_44();
  public int GetStyleMaxValue()
    { return GetStyleMaxValue_44(); }

  private native int GetStyle_45();
  public int GetStyle()
    { return GetStyle_45(); }

  private native void SetStyleToFilled_46();
  public void SetStyleToFilled()
    { SetStyleToFilled_46(); }

  private native void SetStyleToOutline_47();
  public void SetStyleToOutline()
    { SetStyleToOutline_47(); }

  private native void SetMargin_48(double id0);
  public void SetMargin(double id0)
    { SetMargin_48(id0); }

  private native double GetMargin_49();
  public double GetMargin()
    { return GetMargin_49(); }

  private native void SetBackgroundColor_50(double id0,double id1,double id2);
  public void SetBackgroundColor(double id0,double id1,double id2)
    { SetBackgroundColor_50(id0,id1,id2); }

  private native void SetBackgroundColor_51(double id0[]);
  public void SetBackgroundColor(double id0[])
    { SetBackgroundColor_51(id0); }

  private native double[] GetBackgroundColor_52();
  public double[] GetBackgroundColor()
    { return GetBackgroundColor_52(); }

  private native void SetBackgroundOpacity_53(double id0);
  public void SetBackgroundOpacity(double id0)
    { SetBackgroundOpacity_53(id0); }

  private native double GetBackgroundOpacityMinValue_54();
  public double GetBackgroundOpacityMinValue()
    { return GetBackgroundOpacityMinValue_54(); }

  private native double GetBackgroundOpacityMaxValue_55();
  public double GetBackgroundOpacityMaxValue()
    { return GetBackgroundOpacityMaxValue_55(); }

  private native double GetBackgroundOpacity_56();
  public double GetBackgroundOpacity()
    { return GetBackgroundOpacity_56(); }

  private native long GetAnchorTransform_57();
  public vtkCoordinate GetAnchorTransform() {
    long temp = GetAnchorTransform_57();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ReleaseGraphicsResources_58(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_58(id0); }

  public vtkLabelPlacementMapper() { super(); }

  public vtkLabelPlacementMapper(long id) { super(id); }
  public native long   VTKInit();

}
